@@ -16,6 +16,7 @@ import pytest
 
 import pyfakefs.pytest_tests.example as example
 from pyfakefs.fake_filesystem_unittest import Patcher
+from pyfakefs.pytest_tests import unhashable
 
 
 @pytest.mark.xfail
@@ -41,6 +42,11 @@ def test_example_file_passing_using_patcher():
         check_that_example_file_is_in_fake_fs()
 
 
+def test_unhashable(fs):
+    # regression test for #923
+    print(unhashable)
+
+
 def check_that_example_file_is_in_fake_fs():
     with open(example.EXAMPLE_FILE) as file:
         assert file.read() == "stuff here"
