@@ -112,7 +112,7 @@ class TestPyfakefsUnittest(TestPyfakefsUnittestBase):  # pylint: disable=R0904
         with open("/fake_file.txt", encoding="utf8") as f:
             content = f.read()
         self.assertEqual(
-            "This test file was created using the " "open() function.\n",
+            "This test file was created using the open() function.\n",
             content,
         )
 
@@ -120,12 +120,12 @@ class TestPyfakefsUnittest(TestPyfakefsUnittestBase):  # pylint: disable=R0904
         """Fake io module is bound"""
         self.assertFalse(os.path.exists("/fake_file.txt"))
         with io_open("/fake_file.txt", "w", encoding="utf8") as f:
-            f.write("This test file was created using the" " io.open() function.\n")
+            f.write("This test file was created using the io.open() function.\n")
         self.assertTrue(self.fs.exists("/fake_file.txt"))
         with open("/fake_file.txt", encoding="utf8") as f:
             content = f.read()
         self.assertEqual(
-            "This test file was created using the " "io.open() function.\n",
+            "This test file was created using the io.open() function.\n",
             content,
         )
 
@@ -456,6 +456,36 @@ class AdditionalSkipNamesModuleTest(fake_filesystem_unittest.TestCase):
         pyfakefs.tests.import_as_example.return_this_file_path()
 
 
+class RuntimeSkipModuleTest(fake_filesystem_unittest.TestCase):
+    """Emulates skipping a module using RUNTIME_SKIPMODULES.
+    Not all functionality implemented for skip modules will work here."""
+
+    def setUp(self):
+        Patcher.RUNTIME_SKIPMODULES.update(
+            {"pyfakefs.tests.import_as_example": ["pyfakefs.tests.import_"]}
+        )
+        self.setUpPyfakefs()
+
+    def tearDown(self):
+        del self.patcher.RUNTIME_SKIPMODULES["pyfakefs.tests.import_as_example"]
+
+    def test_fake_path_does_not_exist1(self):
+        self.fs.create_file("foo")
+        self.assertFalse(pyfakefs.tests.import_as_example.check_if_exists1("foo"))
+
+    def test_fake_path_does_not_exist2(self):
+        self.fs.create_file("foo")
+        self.assertFalse(pyfakefs.tests.import_as_example.check_if_exists2("foo"))
+
+    def test_fake_path_does_not_exist3(self):
+        self.fs.create_file("foo")
+        self.assertFalse(pyfakefs.tests.import_as_example.check_if_exists3("foo"))
+
+    def test_fake_path_does_not_exist4(self):
+        self.fs.create_file("foo")
+        self.assertFalse(pyfakefs.tests.import_as_example.check_if_exists4("foo"))
+
+
 class FakeExampleModule:
     """Used to patch a function that uses system-specific functions that
     cannot be patched automatically."""
@@ -541,13 +571,8 @@ class NoRootUserTest(fake_filesystem_unittest.TestCase):
 
 class PauseResumeTest(fake_filesystem_unittest.TestCase):
     def setUp(self):
-        self.real_temp_file = None
         self.setUpPyfakefs()
 
-    def tearDown(self):
-        if self.real_temp_file is not None:
-            self.real_temp_file.close()
-
     def test_pause_resume(self):
         fake_temp_file = tempfile.NamedTemporaryFile()
         self.assertTrue(self.fs.exists(fake_temp_file.name))
@@ -555,11 +580,11 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         self.pause()
         self.assertTrue(self.fs.exists(fake_temp_file.name))
         self.assertFalse(os.path.exists(fake_temp_file.name))
-        self.real_temp_file = tempfile.NamedTemporaryFile()
-        self.assertFalse(self.fs.exists(self.real_temp_file.name))
-        self.assertTrue(os.path.exists(self.real_temp_file.name))
+        real_temp_file = tempfile.NamedTemporaryFile()
+        self.assertFalse(self.fs.exists(real_temp_file.name))
+        self.assertTrue(os.path.exists(real_temp_file.name))
         self.resume()
-        self.assertFalse(os.path.exists(self.real_temp_file.name))
+        self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
     def test_pause_resume_fs(self):
@@ -572,15 +597,15 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         self.fs.pause()
         self.assertTrue(self.fs.exists(fake_temp_file.name))
         self.assertFalse(os.path.exists(fake_temp_file.name))
-        self.real_temp_file = tempfile.NamedTemporaryFile()
-        self.assertFalse(self.fs.exists(self.real_temp_file.name))
-        self.assertTrue(os.path.exists(self.real_temp_file.name))
+        real_temp_file = tempfile.NamedTemporaryFile()
+        self.assertFalse(self.fs.exists(real_temp_file.name))
+        self.assertTrue(os.path.exists(real_temp_file.name))
         # pause does nothing if already paused
         self.fs.pause()
-        self.assertFalse(self.fs.exists(self.real_temp_file.name))
-        self.assertTrue(os.path.exists(self.real_temp_file.name))
+        self.assertFalse(self.fs.exists(real_temp_file.name))
+        self.assertTrue(os.path.exists(real_temp_file.name))
         self.fs.resume()
-        self.assertFalse(os.path.exists(self.real_temp_file.name))
+        self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
     def test_pause_resume_contextmanager(self):
@@ -590,10 +615,10 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         with Pause(self):
             self.assertTrue(self.fs.exists(fake_temp_file.name))
             self.assertFalse(os.path.exists(fake_temp_file.name))
-            self.real_temp_file = tempfile.NamedTemporaryFile()
-            self.assertFalse(self.fs.exists(self.real_temp_file.name))
-            self.assertTrue(os.path.exists(self.real_temp_file.name))
-        self.assertFalse(os.path.exists(self.real_temp_file.name))
+            real_temp_file = tempfile.NamedTemporaryFile()
+            self.assertFalse(self.fs.exists(real_temp_file.name))
+            self.assertTrue(os.path.exists(real_temp_file.name))
+        self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
     def test_pause_resume_fs_contextmanager(self):
@@ -603,10 +628,10 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         with Pause(self.fs):
             self.assertTrue(self.fs.exists(fake_temp_file.name))
             self.assertFalse(os.path.exists(fake_temp_file.name))
-            self.real_temp_file = tempfile.NamedTemporaryFile()
-            self.assertFalse(self.fs.exists(self.real_temp_file.name))
-            self.assertTrue(os.path.exists(self.real_temp_file.name))
-        self.assertFalse(os.path.exists(self.real_temp_file.name))
+            real_temp_file = tempfile.NamedTemporaryFile()
+            self.assertFalse(self.fs.exists(real_temp_file.name))
+            self.assertTrue(os.path.exists(real_temp_file.name))
+        self.assertFalse(os.path.exists(real_temp_file.name))
         self.assertTrue(os.path.exists(fake_temp_file.name))
 
     def test_pause_resume_without_patcher(self):
@@ -614,6 +639,13 @@ class PauseResumeTest(fake_filesystem_unittest.TestCase):
         with self.assertRaises(RuntimeError):
             fs.resume()
 
+    def test_that_tempfile_is_patched_after_resume(fs):
+        """Regression test for #1098"""
+        fs.pause()
+        fs.resume()
+        with tempfile.NamedTemporaryFile():
+            pass
+
 
 class PauseResumePatcherTest(fake_filesystem_unittest.TestCase):
     def test_pause_resume(self):
@@ -956,5 +988,42 @@ class TestTempPathCreation(fake_filesystem_unittest.TestCase):
         self.check_write_tmp_after_reset(OSType.WINDOWS)
 
 
+@unittest.skipIf(sys.version_info < (3, 8), "Not available before Python 3.8")
+class FakeImportTest(fake_filesystem_unittest.TestCase):
+    """Checks that a fake module can be imported in AUTO patch mode."""
+
+    def setUp(self):
+        self.setUpPyfakefs(patch_open_code=PatchMode.AUTO)
+
+    def test_simple_fake_import(self):
+        fake_module_path = Path("/") / "site-packages" / "fake_module.py"
+        self.fs.create_file(fake_module_path, contents="number = 42")
+        sys.path.insert(0, str(fake_module_path.parent))
+        module = importlib.import_module("fake_module")
+        del sys.path[0]
+        assert module.__name__ == "fake_module"
+        assert module.number == 42
+
+    def test_fake_import_dotted_module(self):
+        fake_pkg_path = Path("/") / "site-packages"
+        self.fs.create_file(fake_pkg_path / "fakepkg" / "__init__.py")
+        fake_module_path = fake_pkg_path / "fakepkg" / "fake_module.py"
+        self.fs.create_file(fake_module_path, contents="number = 42")
+        sys.path.insert(0, str(fake_pkg_path))
+        module = importlib.import_module("fakepkg.fake_module")
+        del sys.path[0]
+        assert module.__name__ == "fakepkg.fake_module"
+        assert module.number == 42
+
+    def test_fake_relative_import(self):
+        fake_module_path = Path("site-packages") / "fake_module.py"
+        self.fs.create_file(fake_module_path, contents="number = 42")
+        sys.path.insert(0, str(fake_module_path.parent))
+        module = importlib.import_module("fake_module")
+        del sys.path[0]
+        assert module.__name__ == "fake_module"
+        assert module.number == 42
+
+
 if __name__ == "__main__":
     unittest.main()
